---
icon: octicons/sponsor-tiers-24
---

First of all, thank you for your idea of supporting this project! ❤️

!!! tip "Tip"

    If you like the project but don't have the means to give financial support, that's okay too. There are other easy ways to support the project and show your gratitude, and we are also very happy, such as star the project! ⭐

Here are all the ways to sponsor:

=== "🟢 WeChat Appreciation Code"

    <p align="center">
    <img width="512" alt="weChat" src="../wechat.png"/>
    </p>

=== "🔵 Others"

    !!! failure "Not supported"

        We're sorry, but other sponsorship methods are not supported at this time

Please include some information when sponsoring, in the following format:

```linenums="0"
maliang [your nickname or your GitHub Username]
```

I'll put `[your nickname or your GitHub Username]` and the time and amount of your sponsorship below! Of course, you can also be anonymous.

This page will be updated on an ongoing basis to list as many people as possible who have given monetary sponsorship!

This page is not updated automatically, but manually by me, so please understand that the sponsored list may not be updated in time.

| 🕓 Date { data-sort-method=min } |            😀 Sponsors             |    💰 Amount { data-sort-method=number }    |        ❤️ Methods         |
| :-----------------------------: | :-------------------------------: | :----------------------------------------: | :----------------------: |
|       2025-02-24 11:47:33       |     <https://github.com/3190>     |                   ¥6.00                    | WeChat Appreciation Code |
|       2025-02-11 21:22:00       |             Mooshed88             |                   ¥5.00                    | WeChat Appreciation Code |
|       2025-02-08 14:47:30       |            龙骑士Chris            |                   ¥10.00                   | WeChat Appreciation Code |
|       2025-01-21 09:34:57       |  <https://github.com/OnesoftQwQ>  |                   ¥5.00                    | WeChat Appreciation Code |
|       2024-09-15 21:33:48       | <https://github.com/lingtian1462> |                   ¥11.11                   | WeChat Appreciation Code |
|       2024-09-07 10:55:47       |   <https://github.com/Spra0125>   |                   ¥10.00                   | WeChat Appreciation Code |
|       2024-08-14 10:19:56       |              junfeng              |                   ¥5.00                    | WeChat Appreciation Code |
|       2024-08-14 10:19:15       |  <https://github.com/shu-shu-1>   | ¥60.00 :crown:{ title="Sponsor the Most" } | WeChat Appreciation Code |
|       2024-08-14 09:41:03       |             ssrr2329              |                   ¥50.00                   | WeChat Appreciation Code |
|       2024-08-13 19:03:52       |  <https://github.com/shu-shu-1>   |                   ¥21.00                   | WeChat Appreciation Code |
|       2024-07-11 23:01:34       |               Lau9                |                   ¥9.99                    | WeChat Appreciation Code |
|       2024-07-11 23:00:50       |            curios-city            |                   ¥8.88                    | WeChat Appreciation Code |
|       2024-07-11 22:59:39       |             ShenNong              |                   ¥7.77                    | WeChat Appreciation Code |
|       2024-06-23 01:30:14       |                                   |                   ¥6.66                    | WeChat Appreciation Code |
|       2024-06-03 21:48:05       | <https://github.com/TotoWang-hhh> |                   ¥1.00                    | WeChat Appreciation Code |
